@@ -1,8 +1,7 @@
 __author__ = "Damon May"
 
 import json
-import pandas as pd
-from typing import Dict, Any, Tuple
+from typing import Dict, Any
 from jamstats.data.game_data import DerbyGame
 from jamstats.data.json_to_pandas import load_json_derby_game
 
